@@ -9,10 +9,12 @@ def main():
                         help='Search PyBites Python tips')
     parser.add_argument("-p", "--pager", action='store_true',
                         help='Go through the resulting tips one by one')
+    parser.add_argument("-c", "--colors", action='store_true',
+                        help='Do syntax highlighting on the snippets')
 
     args = parser.parse_args()
 
-    pb_tips = PyBitesTips(use_pager=args.pager)
+    pb_tips = PyBitesTips(use_pager=args.pager, use_colors=args.colors)
     if args.search:
         tips = pb_tips.filter_tips(args.search)
         pb_tips.show_tips(tips)
